#!/bin/sh
APKG_PATH=/usr/local/AppCentral/jdownloader

source ${APKG_PATH}/CONTROL/env.sh
java_exec=${JAVA_HOME}/bin/java

. /lib/lsb/init-functions

CRONDIR=/usr/builtin/etc/crontabs

adapt_param(){
### copied from web site 
ARGJ=""
MN="0"
HR="*/1"
MEMORY=$(free -m | grep Mem: | tr -s " " | cut -f 2 -d " ")
if [ -z "$MEMORY" ] ; then
	echo "keep default"
elif [ $MEMORY -gt 2048 ] ; then
	MN="0"
	HR="*/2"
elif [ $MEMORY -lt 512 ] ; then
	MN="0"
	HR="*/1"
else
	MN="0,30"
	HR="*"
	ARGJ="-XX:+UseParNewGC -XX:MaxHeapFreeRatio=0 -XX:MinHeapFreeRatio=0 -Xms2M -Xmx150M -Xmaxf0"
fi
}

add_in_cron(){
	grep -q jd_clean_tmp ${CRONDIR}/root
	if [ $? -eq 0 ] ; then
	## del it in case of change in config
		/bin/sed -i '/jd_clean_tmp/d' ${CRONDIR}/root
	fi
	/bin/echo "0 0 1 * * ${APKG_PATH}/CONTROL/start_stop.sh jd_clean_tmp" >> ${CRONDIR}/root
	grep -q jd_clean_cache ${CRONDIR}/root
        if [ $? -eq 0 ] ; then
        ## del it in case of change in config
		/bin/sed -i '/jd_clean_cache/d' ${CRONDIR}/root
	fi
	/bin/echo "$MN $HR * * * ${APKG_PATH}/CONTROL/start_stop.sh jd_clean_cache" >> ${CRONDIR}/root
	/bin/sync
}
rm_in_cron(){
	grep -q jd_clean_tmp ${CRONDIR}/root
        if [ $? -eq 0 ] ; then
               /bin/sed -i '/jd_clean_tmp/d' ${CRONDIR}/root
        fi
	grep -q jd_clean_cache ${CRONDIR}/root
        if [ $? -eq 0 ] ; then
               /bin/sed -i '/jd_clean_cache/d' ${CRONDIR}/root
        fi
	/bin/sync
}

web_link(){
	if [ ! -e /share/Web/jdownloader ] ; then
		ln -s ${APKG_PATH}/www /share/Web/jdownloader
	fi
}
rm_web_link(){
	if [ ! -e /share/Web/jdownloader ] ; then
		rm -f /share/Web/jdownloader
	fi
}

case "$1" in
	start)
		if [ ! -e ${APKG_PATH}/.init_done ] ; then
			echo "Please run ${APKG_PATH}/init.sh FIRST"
			syslog  --log 0 --level 0 --user admin --event "Please run ${APKG_PATH}/init.sh "
			exit 1
		fi
	#	web_link
		adapt_param
		## add the cron
		add_in_cron
		cd ${APKG_PATH}/jd
		/usr/bin/nohup ${java_exec} ${ARGJ} -Djava.awt.headless=true -jar ./JDownloader.jar > ${APKG_PATH}/log/jd.out 2>&1 &

	;;
	stop)
		if [ -e ${APKG_PATH}/jd/JDownloader.pid ] ; then
			kill -15 $(cat ${APKG_PATH}/jd/JDownloader.pid)
		fi
		## second chance
		ps -eaf | grep -v grep | grep -q JDownloader
		if [ $? -eq 0 ] ; then
			kill -15 $(ps -eaf | grep -v grep | grep JDownloader | tr -s " " | cut -f 2 -d " ")
		fi
		rm_in_cron
	;;
	restart)
		$0 stop
		sleep 5
		$0 start
	;;
	jd_clean_tmp)
		$0 stop
		sleep 5
		/bin/rm -rf ${APKG_PATH}/jd/tmp/*
		$0 start
	;;
	jd_clean_cache)
		/bin/sh -c "sync; echo 3 > /proc/sys/vm/drop_caches"
	;;
	status)
		ps -eaf | grep -v grep | grep JDownloader
	;;
	set_java_home)
		if [ -e "$2" ] ; then
			echo "set JAVA_HOME to $2 "
			echo "### here change JAVA_HOME" > ${APKG_PATH}/java_home
			echo "export JAVA_HOME=$2 " >> ${APKG_PATH}/java_home
		else
			echo "PATH : $2 don't exist ... NO CHANGE "
		fi
	;;
	reset_java_home)
		echo "### here change JAVA_HOME" > ${APKG_PATH}/java_home
		echo "export JAVA_HOME=/usr/local/AppCentral/jre" >> ${APKG_PATH}/java_home
	;;
	*)
		echo "Usage :"
		echo "$0 start|stop|restart|status"
		echo "$0 set_java_home PATH_to_JRE_folder "
		echo "$0 reset_java_home (return to default /usr/local/AppCentral/jre "
	;;
esac

